==> v0.4.zip: rangitaki/config.php <==
<?php
// This is the configuration file. You can configure here all necessary (and possible) options without editing the index.php file.
// Every line has an description about what you can change here. Don't delete any strings. You can set your value after the '=' sign and between the apostrophes.
// Make sure that every line ends with an semicolon (';').
// Blog Title - Set here an individual title of your blog by replacing Rangitaki Blog with it.
$blogtitle = 'Rangitaki Blog';
// Blog Author - Set here your name 
$blogauthor = 'Marcel Kapfer';
// Blog description
$blogdescription = 'Rangitaki - A PHP blog engine without any database dependency';
// Blog favicon - enter here the path to your favicon
$blogfavicon = '../res/favicon.png';
// Home - set yes if you want to link to your homepage and no if not
$bloghome = 'yes';
// Home URL - Set here the url to your main page. Either relative (e.g. '../') or absolute (e.g. 'http://github.com')
$bloghomeurl = '../';
// Home name - Set here an individual name for your main page
$bloghomename = 'Home';
// Intro - set yes if you have a blog intro and no if you don't have one
$blogintro = 'yes';
// Disqus - Provide here your Disqus shortname. Leave empty if you don't want to use it.
$blogdisqus = 'rangitaki';
// Google Analytics - Provide here your Google Analytics Tracking-ID. Leave empty if you don't want to use it.
$bloganalytics = '';
// Footer - set here the text for your footer (e.g. a copyright info).  You can replace the whole text after the '=' with your own one.
$blogfooter = 'Rangitaki ' .  date("Y") . ' <a href="https://github.com/mmk2410/Rangitaki" target="blank">github.com/mmk2410/Rangitaki</a>';
// This enables the optional online post upload. Please read the documentation before you enable it.
$post_upload = 'no'
?>

==> v0.6.zip: rangitaki/config.php <==
<?php

// This is the configuration file. You can configure here all necessary (and possible) options without editing the index.php file.
// Every line has an description about what you can change here. Don't delete any strings. You can set your value after the '=' sign and between the apostrophes.
// Make sure that every line ends with an semicolon (';').
// Blog Title - Set here an individual title of your blog by replacing Rangitaki Blog with it.
$blogtitle = 'Rangitaki Blog';
// Blog Author - Set here your name 
$blogauthor = 'Marcel Kapfer';
// Blog description
$blogdescription = 'Rangitaki - A PHP blogging engine without any database dependency';
// Blog favicon - enter here the path to your favicon
$blogfavicon = '../res/favicon.png';
// Home - set yes if you want to link to your homepage and no if not
$bloghome = 'yes';
// Home URL - Set here the url to your main page. Either relative (e.g. '../') or absolute (e.g. 'http://github.com')
$bloghomeurl = '../';
// Home name - Set here an individual name for your main page
$bloghomename = 'Home';
// Main Blog name -> Set a specific name for your name blog
// This value is empty by default
$blogmainname = '';
// Intro - set yes if you have a blog intro and no if you don't have one
$blogintro = 'yes';
// Disqus - Provide here your Disqus shortname. Leave empty if you don't want to use it.
$blogdisqus = 'rangitaki';
// Share FAB - this enables or disables the share button
$sharefab = 'yes';
// Google Analytics - Provide here your Google Analytics Tracking-ID. Leave empty if you don't want to use it.
$bloganalytics = '';
// Footer - set here the text for your footer (e.g. a copyright info).  You can replace the whole text after the '=' with your own one.
$blogfooter = 'Rangitaki ' . date("Y") . ' <a href="https://github.com/mmk2410/Rangitaki" target="blank">github.com/mmk2410/Rangitaki</a>';
// This enables the optional rangitaki control center. Please read the documentation before you enable it.
$rcc = 'no';
// Here you can disable and enable the navigation menu. Usefull if you have no subblogs and no home directory
$nav_drawer = 'yes';
// Set here the name of your theme. Read the documentation for more themes
$theme = 'material-light';
// Set here your language. The file must exist in the lang directory
$language = "en";
